summaryrefslogtreecommitdiff
path: root/src/lib/timer.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2013-12-19 19:21:50 +0000
committerCarl Hetherington <cth@carlh.net>2013-12-19 19:21:50 +0000
commitf434d010e13ddf834a552be8833abb6f89767fe8 (patch)
treea827edbfac982a93cc7b9641677f0f4c1de6f849 /src/lib/timer.h
parent8cd68046c5e71ceaed90847aee2ca00c0ccf2e39 (diff)
Fix erroneous rename.
Diffstat (limited to 'src/lib/timer.h')
-rw-r--r--src/lib/timer.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/lib/timer.h b/src/lib/timer.h
index 8ec392aa6..4a5aa12de 100644
--- a/src/lib/timer.h
+++ b/src/lib/timer.h
@@ -29,16 +29,16 @@
#include <map>
#include <sys/time.h>
-/** @class PeriodDCPTimer
+/** @class PeriodTimer
* @brief A class to allow timing of a period within the caller.
*
* On destruction, it will output the time since its construction.
*/
-class PeriodDCPTimer
+class PeriodTimer
{
public:
- PeriodDCPTimer (std::string n);
- ~PeriodDCPTimer ();
+ PeriodTimer (std::string n);
+ ~PeriodTimer ();
private:
@@ -48,19 +48,19 @@ private:
struct timeval _start;
};
-/** @class StateDCPTimer
+/** @class StateTimer
* @brief A class to allow measurement of the amount of time a program
* spends in one of a set of states.
*
* Once constructed, the caller can call set_state() whenever
* its state changes. When StateDCPTimer is destroyed, it will
* output (to cout) a summary of the time spent in each state.
*/
-class StateDCPTimer
+class StateTimer
{
public:
- StateDCPTimer (std::string n, std::string s);
- ~StateDCPTimer ();
+ StateTimer (std::string n, std::string s);
+ ~StateTimer ();
void set_state (std::string s);
@@ -48,19 +48,19 @@ private:
*
* Once constructed, the caller can call set_state() whenever
- * its state changes. When StateDCPTimer is destroyed, it will
+ * its state changes. When StateTimer is destroyed, it will
* output (to cout) a summary of the time spent in each state.
*/